function [sigma_aquschlange] = sigma_aquschlangestart(sigma_ai, n_i, k, N_D, N_quer, D_mmin)

%Funktion bestimmt der Startwert sigma_aquschlange fr die Iteration von
%A_kon nach dem Verfahren Miner-elementar, vgl. Kap. 4.4.3.5.2, 
%FKM-Richtlinie 6. Aufl. 2012.
%
%Eingaben:
%sigma_ai = Kollektivamplituden passend zu n_i (Spaltenvektor)
%n_i      = Kollektivstufenhufigkeiten passend zu sigma_ai (Spaltenvektor)
%k        = Whlerlinienneigung nach Kap. 4.4.3.4
%N_D      = Knickpunktzyklenzahl der Bauteil-Whlerlinie nach Kap. 4.4.3.4
%N_quer   = Geforderte Zyklenzahl nach Kapitel 4.1.3.1
%D_mmin   = Untergrenze der effektiven Miner-Summe nach Tab. 4.4.4
%
%Ausgaben:
%sigma_aquschlange = Iterationsstartwert A_kon
%
%Aufrufbeispiel:
%[sigma_aquschlange] = sigma_aquschlangestart(sigma_ai, n_i, k, N_D, N_quer, D_mmin)
%
%nderungshistorie:
%02. November 2016:
%   Dr.-Ing. C. Mller
%       Erstausgabe


%Summiere alle Anteile fr A_ele auf (Gleichung 4.4.55):
A_ele = 0;
for i=1:length(sigma_ai)
    A_ele = A_ele + n_i(i)/N_quer*(sigma_ai(i)/sigma_ai(1))^k;
end
A_ele = 1/A_ele;


%Bestimme D_m (Gleichung 4.4.51 mit darunterstehender Maximumbedingung):
D_m = 2 / A_ele^0.25;

if D_m < D_mmin
    D_m = D_mmin;
elseif D_m > 1
    D_m = 1;
end


%Berechne K_BKele (Gleichung 4.4.50 mit Minimumbedingung auf S. 105):
K_BKele = (A_ele*N_D*D_m / N_quer)^(1/k);

if K_BKele < 1
    K_BKele = 1;
end


%Berechne sigma_aquschlange (Gleichung 4.4.56):
sigma_aquschlange = sigma_ai(1) / K_BKele;